==> seedsui-react-5.8.44.tgz: package/lib/TreePicker/Tree/utils/getTreeData.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
import React from 'react';
import HighlightKeyword from "./../../../HighlightKeyword";

// 构建渲染数据, 支持关键字搜索
function getTreeData(_ref) {
  var _list$, _list$2;
  var list = _ref.list,
    loadedKeys = _ref.loadedKeys,
    onlyLeafCheck = _ref.onlyLeafCheck,
    keyword = _ref.keyword,
    itemRender = _ref.itemRender,
    _onClick = _ref.onClick;
  if (
  // 必须是数组
  !Array.isArray(list) || !list.length ||
  // 必须有id和name属性
  !((_list$ = list[0]) !== null && _list$ !== void 0 && _list$.id) || !((_list$2 = list[0]) !== null && _list$2 !== void 0 && _list$2.name)) {
    console.error('SeedsUI TreePicker.Tree: list参数不正确');
    return [];
  }
  // 关键字搜索
  var loop = function loop(data) {
    return data.map(function (item) {
      // 行内容
      var titleContentNode = /*#__PURE__*/React.createElement(HighlightKeyword, {
        text: item.name,
        keyword: keyword
      });

      // 自定义渲染行内容
      if (typeof itemRender === 'function') {
        var customTitleNode = itemRender(item, {
          keyword: keyword
        });
        if (customTitleNode) {
          titleContentNode = customTitleNode;
        }
      }

      // 自定义渲染行
      var titleNode = /*#__PURE__*/React.createElement("div", {
        className: "rc-tree-title-wrapper",
        onClick: function onClick(e) {
          e.stopPropagation();
          typeof _onClick === 'function' && _onClick(item);
        }
      }, titleContentNode);

      // 子节点递归
      if (Array.isArray(item.children) && item.children.length) {
        var parentDisabled = typeof onlyLeafCheck === 'function' ? onlyLeafCheck(item) === false : onlyLeafCheck;
        return _objectSpread(_objectSpread({
          // 仅允许选中末级节点，父节点则不允许选中
          disabled: parentDisabled
        }, item), {}, {
          title: titleNode,
          children: loop(item.children)
        });
      }

      // 叶子节点，异步加载的父级节点(不在loadedKeys集合中的为父节点)
      var leafDisabled = false;
      // 自定义设置叶子节点是否禁用
      if (typeof onlyLeafCheck === 'function') {
        leafDisabled = onlyLeafCheck(item) === false;
      }
      // 仅允许选择末级节点的情况下, 异步加载, 如果有子节点则禁用
      else if (onlyLeafCheck && loadedKeys && loadedKeys.includes(item.id) === false) {
        leafDisabled = true;
      }
      return _objectSpread(_objectSpread({
        disabled: leafDisabled
      }, item), {}, {
        title: titleNode
      });
    });
  };
  return loop(list);
}
export default getTreeData;

==> seedsui-react-5.8.57.tgz: package/lib/TreePicker/Tree/utils/getTreeData.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
import React from 'react';
import HighlightKeyword from "./../../../HighlightKeyword";

// 构建渲染数据, 支持关键字搜索
function getTreeData(_ref) {
  var _list$, _list$2;
  var list = _ref.list,
    loadedKeys = _ref.loadedKeys,
    onlyLeafCheck = _ref.onlyLeafCheck,
    keyword = _ref.keyword,
    itemRender = _ref.itemRender,
    _onClick = _ref.onClick;
  if (
  // 必须是数组
  !Array.isArray(list) || !list.length ||
  // 必须有id和name属性
  !((_list$ = list[0]) !== null && _list$ !== void 0 && _list$.id) || !((_list$2 = list[0]) !== null && _list$2 !== void 0 && _list$2.name)) {
    console.error('SeedsUI TreePicker.Tree: list参数不正确');
    return [];
  }
  // 关键字搜索
  var loop = function loop(data) {
    return data.map(function (item) {
      // 行内容
      var titleContentNode = /*#__PURE__*/React.createElement(HighlightKeyword, {
        text: item.name,
        keyword: keyword
      });

      // 自定义渲染行内容
      if (typeof itemRender === 'function') {
        var customTitleNode = itemRender(item, {
          keyword: keyword
        });
        if (customTitleNode) {
          titleContentNode = customTitleNode;
        }
      }

      // 自定义渲染行
      var titleNode = /*#__PURE__*/React.createElement("span", {
        className: "rc-tree-title-wrapper",
        onClick: function onClick(e) {
          e.stopPropagation();
          typeof _onClick === 'function' && _onClick(item);
        }
      }, titleContentNode);

      // 子节点递归
      if (Array.isArray(item.children) && item.children.length) {
        var parentDisabled = typeof onlyLeafCheck === 'function' ? onlyLeafCheck(item) === false : onlyLeafCheck;
        return _objectSpread(_objectSpread({
          // 仅允许选中末级节点，父节点则不允许选中
          disabled: parentDisabled
        }, item), {}, {
          title: titleNode,
          children: loop(item.children)
        });
      }

      // 叶子节点，异步加载的父级节点(不在loadedKeys集合中的为父节点)
      var leafDisabled = false;
      // 自定义设置叶子节点是否禁用
      if (typeof onlyLeafCheck === 'function') {
        leafDisabled = onlyLeafCheck(item) === false;
      }
      // 仅允许选择末级节点的情况下, 异步加载, 如果有子节点则禁用
      else if (onlyLeafCheck && loadedKeys && loadedKeys.includes(item.id) === false) {
        leafDisabled = true;
      }
      return _objectSpread(_objectSpread({
        disabled: leafDisabled
      }, item), {}, {
        title: titleNode
      });
    });
  };
  return loop(list);
}
export default getTreeData;
